@@ -1,9 +1,10 @@
-from typing import Tuple
+from typing import Optional, Tuple
 
 import click
 
 from ..decorators import require_bins, require_login
 from ..helpers.ansible import run_ansible
+from ..helpers.options import aws_profile_options
 from . import GlobalOptions
 from .sym import sym
 
@@ -14,10 +15,22 @@ from .sym import sym
 )
 @click.argument("resource")
 @click.argument("command", nargs=-1)
+@aws_profile_options
 @click.make_pass_decorator(GlobalOptions)
 @require_bins("ansible", "aws", "session-manager-plugin")
 @require_login
-def ansible(options: GlobalOptions, resource: str, command: Tuple[str, ...]) -> None:
+def ansible(
+    options: GlobalOptions,
+    resource: str,
+    command: Tuple[str, ...],
+    ansible_aws_profile: Optional[str],
+    ansible_sym_resource: Optional[str],
+) -> None:
     """Use approved creds for RESOURCE to run an Ansible command."""
     client = options.create_saml_client(resource)
-    run_ansible(client, command)
+    run_ansible(
+        client,
+        command,
+        ansible_aws_profile=ansible_aws_profile,
+        ansible_sym_resource=ansible_sym_resource,
+    )
