@@ -2,7 +2,7 @@ from typing import Optional, Tuple
 
 from ..decorators import intercept_errors, run_subprocess
 from ..helpers.params import get_ssh_user
-from ..helpers.ssh import SSHKey
+from ..helpers.ssh import SSHKeyPath
 from ..saml_clients.aws_profile import AwsProfile
 
 
@@ -30,6 +30,6 @@ def run_ansible(
         *command,
         f"--ssh-common-args={ssh_args}",
         f"--user={get_ssh_user()}",
-        f"--private-key={str(SSHKey)}",
+        f"--private-key={str(client.subconfig(SSHKeyPath))}",
         suppress_=True,
     )
