@@ -29,7 +29,9 @@ PARAMS: Dict[str, OrgParams] = {
         "resource_env_var": "ENVIRONMENT",
         "ssh_user": "ubuntu",
         "domain": "launchdarkly.com",
-        "aws_saml_url": "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
+        "aws_saml_url": (
+            "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272"
+        ),
         "aws_okta_params": {
             "mfa_provider": "OKTA",
             "mfa_factor_type": "push",
@@ -69,6 +71,9 @@ PARAMS: Dict[str, OrgParams] = {
         "resource_env_var": "ENVIRONMENT",
         "ssh_user": "ubuntu",
         "domain": "symops.io",
+        "aws_saml_url": (
+            "https://dev-291131.okta.com/home/amazon_aws/0oaqlmsn7GMVgAyBK4x6/272"
+        ),
         "aws_okta_params": {},
         "saml2aws_params": {"mfa": "Auto"},
         "profiles": {
@@ -76,7 +81,6 @@ PARAMS: Dict[str, OrgParams] = {
                 display_name="Test",
                 region="us-east-1",
                 arn="arn:aws:iam::838419636750:role/SSMTestRole",
-                aws_saml_url="https://dev-291131.okta.com/home/amazon_aws/0oaqadixzIIdZqbTx4x6/272",
             ),
         },
     },
