@@ -1,28 +1,48 @@
 import re
 import sys
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from configparser import ConfigParser
-from typing import ClassVar, Protocol, Type
+from typing import ClassVar, Final, Optional, Type
 from urllib.parse import urlsplit
 
 from ..errors import CliError
 from ..helpers import segment
+from ..helpers.config import SymConfigFile
 from ..helpers.params import Profile, get_aws_saml_url, get_profile
 
 
-class SAMLClient(Protocol):
+class SAMLClient(ABC):
     binary: ClassVar[str]
     resource: str
     debug: bool
+    config_file: Final[SymConfigFile]
+    _config: Optional[ConfigParser]
 
-    @abstractmethod
     def __init__(self, resource: str, *, debug: bool) -> None:
-        raise NotImplementedError
+        self.resource = resource
+        self.debug = debug
+        self._config = None
 
     @abstractmethod
     def exec(self, *args: str, **opts: str) -> None:
         raise NotImplementedError
 
+    @abstractmethod
+    def _ensure_config(self, profile: Profile) -> ConfigParser:
+        raise NotImplementedError
+
+    def ensure_config(self) -> ConfigParser:
+        if not self._config:
+            config = self._ensure_config(self.get_profile())
+            with self.config_file as f:
+                config.write(f)
+            self.dconfig(config)
+            self._config = config
+        return self._config
+
+    def subconfig(self, file_name):
+        return SymConfigFile(resource=self.resource, file_name=file_name)
+
     def dprint(self, s: str):
         if self.debug:
             print(f"{s}\n")
