@@ -1,6 +1,6 @@
 from configparser import ConfigParser
 from pathlib import Path
-from typing import Final, Iterator, Tuple
+from typing import Final, Iterator, Optional, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
 from ..errors import ResourceNotSetup, UnavailableResourceError
@@ -8,35 +8,38 @@ from ..helpers.config import SymConfigFile
 from ..helpers.constants import AwsOktaNoRoles, AwsOktaNotSetup
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
-from ..helpers.params import get_aws_okta_params
+from ..helpers.params import Profile, get_aws_okta_params
 from . import SAMLClient
 
-ErrorPatterns = {AwsOktaNoRoles: UnavailableResourceError, AwsOktaNotSetup: ResourceNotSetup}
+ErrorPatterns = {
+    AwsOktaNoRoles: UnavailableResourceError,
+    AwsOktaNotSetup: ResourceNotSetup,
+}
+
 
 class AwsOkta(SAMLClient):
-    __slots__ = ["aws_okta_cfg", "resource", "debug"]
+    __slots__ = ["config_file", "resource", "debug", "_config"]
     binary = "aws-okta"
 
-    aws_okta_cfg: Final[SymConfigFile]
     resource: str
     debug: bool
+    config_file: Final[SymConfigFile]
+    _config: Optional[ConfigParser]
 
     def __init__(self, resource: str, *, debug: bool) -> None:
-        self.aws_okta_cfg = SymConfigFile("aws-okta.cfg")
-        self.resource = resource
-        self.debug = debug
+        super().__init__(resource, debug=debug)
+        self.config_file = SymConfigFile(resource=resource, file_name="aws-okta.cfg")
 
     @intercept_errors(ErrorPatterns)
     @run_subprocess
     @require_bins(binary)
     def exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
         self.log_subprocess_event(args)
-        self._write_aws_okta_config()
-        with push_env("AWS_CONFIG_FILE", str(self.aws_okta_cfg)):
+        self.ensure_config()
+        with push_env("AWS_CONFIG_FILE", str(self.config_file)):
             yield "aws-okta", {"debug": self.debug}, "exec", "sym", "--", *args, opts
 
-    def _write_aws_okta_config(self) -> None:
-        profile = self.get_profile()
+    def _ensure_config(self, profile: Profile) -> ConfigParser:
         config = ConfigParser(default_section="okta")
         config.read_dict(
             {
@@ -48,7 +51,4 @@ class AwsOkta(SAMLClient):
                 },
             }
         )
-        with self.aws_okta_cfg as f:
-            config.write(f)
-
-        self.dconfig(config)
+        return config
