@@ -1,7 +1,7 @@
 import shlex
 from configparser import ConfigParser
 from pathlib import Path
-from typing import Final, Iterator, Tuple
+from typing import Final, Iterator, Optional, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
 from ..errors import UnavailableResourceError
@@ -9,24 +9,24 @@ from ..helpers.config import SymConfigFile
 from ..helpers.constants import Saml2AwsNoRoles
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument, Options, keywords_to_options
-from ..helpers.params import get_saml2aws_params
+from ..helpers.params import Profile, get_saml2aws_params
 from . import SAMLClient
 
 ErrorPatterns = {Saml2AwsNoRoles: UnavailableResourceError}
 
 
 class Saml2Aws(SAMLClient):
-    __slots__ = ["saml2aws_cfg", "resource", "debug"]
+    __slots__ = ["config_file", "resource", "debug", "_config"]
     binary = "saml2aws"
 
-    saml2aws_cfg: Final[SymConfigFile]
     resource: str
     debug: bool
+    config_file: Final[SymConfigFile]
+    _config: Optional[ConfigParser]
 
     def __init__(self, resource: str, *, debug: bool) -> None:
-        self.saml2aws_cfg = SymConfigFile("saml2aws.cfg")
-        self.resource = resource
-        self.debug = debug
+        super().__init__(resource, debug=debug)
+        self.config_file = SymConfigFile(resource=resource, file_name="saml2aws.cfg")
 
     @intercept_errors(ErrorPatterns)
     @run_subprocess
@@ -35,10 +35,10 @@ class Saml2Aws(SAMLClient):
         self.log_subprocess_event(args)
         s2a_options: Options = {
             "verbose": self.debug,
-            "config": str(self.saml2aws_cfg),
+            "config": str(self.config_file),
             "idp_account": "sym",
         }
-        config = self._write_saml2aws_config()
+        config = self.ensure_config()
         # saml2aws exec actually joins all the arguments into a single string and
         # runs it with the shell. So we have to use shlex.join to get around that!
         reparseable = shlex.join(keywords_to_options([*args, opts]))
@@ -46,8 +46,7 @@ class Saml2Aws(SAMLClient):
             yield "saml2aws", s2a_options, "login"  # no-op if session active
             yield "saml2aws", s2a_options, "exec", "--", reparseable
 
-    def _write_saml2aws_config(self) -> ConfigParser:
-        profile = self.get_profile()
+    def _ensure_config(self, profile: Profile) -> ConfigParser:
         saml2aws_params = get_saml2aws_params()
         config = ConfigParser()
         config.read_dict(
@@ -64,9 +63,4 @@ class Saml2Aws(SAMLClient):
                 }
             }
         )
-        with self.saml2aws_cfg as f:
-            config.write(f)
-
-        self.dconfig(config)
-
         return config
